@@ -13,7 +13,7 @@ var jsonNameFromType = map[reflect.Type][]string{
 	reflect.TypeOf(source.StereoscopeImageSourceMetadata{}): {"image"},
 }
 
-func AllNames() []string {
+func AllTypeNames() []string {
 	names := make([]string, 0)
 	for _, t := range AllTypes() {
 		names = append(names, reflect.TypeOf(t).Name())
@@ -32,7 +32,7 @@ func ReflectTypeFromJSONName(name string) reflect.Type {
 	name = strings.ToLower(name)
 	for t, vs := range jsonNameFromType {
 		for _, v := range vs {
-			if v == name {
+			if strings.ToLower(v) == name {
 				return t
 			}
 		}
