@@ -331,7 +331,7 @@ func Test_Cataloger_DefaultClassifiers_PositiveCases(t *testing.T) {
 				Version:   "3.11.2",
 				PURL:      "pkg:generic/python@3.11.2",
 				Locations: locations("python3", "libpython3.11.so.1.0"),
-				Metadata: pkg.BinaryMetadata{
+				Metadata: pkg.BinarySignature{
 					Matches: []pkg.ClassifierMatch{
 						match("python-binary", "python3"),
 						match("python-binary", "libpython3.11.so.1.0"),
@@ -348,7 +348,7 @@ func Test_Cataloger_DefaultClassifiers_PositiveCases(t *testing.T) {
 				Version:   "3.9.13",
 				PURL:      "pkg:generic/python@3.9.13",
 				Locations: locations("python3.9", "libpython3.9.so.1.0"),
-				Metadata: pkg.BinaryMetadata{
+				Metadata: pkg.BinarySignature{
 					Matches: []pkg.ClassifierMatch{
 						match("python-binary", "python3.9"),
 						match("python-binary", "libpython3.9.so.1.0"),
@@ -365,7 +365,7 @@ func Test_Cataloger_DefaultClassifiers_PositiveCases(t *testing.T) {
 				Version:   "3.9.2",
 				PURL:      "pkg:generic/python@3.9.2",
 				Locations: locations("python3.9"),
-				Metadata: pkg.BinaryMetadata{
+				Metadata: pkg.BinarySignature{
 					Matches: []pkg.ClassifierMatch{
 						match("python-binary", "python3.9"),
 					},
@@ -380,7 +380,7 @@ func Test_Cataloger_DefaultClassifiers_PositiveCases(t *testing.T) {
 				Version:   "3.4.10",
 				PURL:      "pkg:generic/python@3.4.10",
 				Locations: locations("python3.4", "libpython3.4m.so.1.0"),
-				Metadata: pkg.BinaryMetadata{
+				Metadata: pkg.BinarySignature{
 					Matches: []pkg.ClassifierMatch{
 						match("python-binary", "python3.4"),
 						match("python-binary", "libpython3.4m.so.1.0"),
@@ -420,7 +420,7 @@ func Test_Cataloger_DefaultClassifiers_PositiveCases(t *testing.T) {
 				Type:      "binary",
 				PURL:      "pkg:generic/python@3.8.16",
 				Locations: locations("dir/python3.8", "python3.8", "libpython3.8.so"),
-				Metadata: pkg.BinaryMetadata{
+				Metadata: pkg.BinarySignature{
 					Matches: []pkg.ClassifierMatch{
 						match("python-binary", "dir/python3.8"),
 						match("python-binary", "python3.8"),
@@ -577,7 +577,7 @@ func Test_Cataloger_DefaultClassifiers_PositiveCases(t *testing.T) {
 				Type:      "binary",
 				PURL:      "pkg:generic/ruby@3.2.1",
 				Locations: locations("ruby", "libruby.so.3.2.1"),
-				Metadata: pkg.BinaryMetadata{
+				Metadata: pkg.BinarySignature{
 					Matches: []pkg.ClassifierMatch{
 						match("ruby-binary", "ruby"),
 						match("ruby-binary", "libruby.so.3.2.1"),
@@ -594,7 +594,7 @@ func Test_Cataloger_DefaultClassifiers_PositiveCases(t *testing.T) {
 				Type:      "binary",
 				PURL:      "pkg:generic/ruby@2.7.7p221",
 				Locations: locations("ruby", "libruby.so.2.7.7"),
-				Metadata: pkg.BinaryMetadata{
+				Metadata: pkg.BinarySignature{
 					Matches: []pkg.ClassifierMatch{
 						match("ruby-binary", "ruby"),
 						match("ruby-binary", "libruby.so.2.7.7"),
@@ -611,7 +611,7 @@ func Test_Cataloger_DefaultClassifiers_PositiveCases(t *testing.T) {
 				Type:      "binary",
 				PURL:      "pkg:generic/ruby@2.6.10p210",
 				Locations: locations("ruby", "libruby.so.2.6.10"),
-				Metadata: pkg.BinaryMetadata{
+				Metadata: pkg.BinarySignature{
 					Matches: []pkg.ClassifierMatch{
 						match("ruby-binary", "ruby"),
 						match("ruby-binary", "libruby.so.2.6.10"),
@@ -774,8 +774,8 @@ func locations(locations ...string) file.LocationSet {
 }
 
 // metadata paths are: realPath, virtualPath
-func metadata(classifier string, paths ...string) pkg.BinaryMetadata {
-	return pkg.BinaryMetadata{
+func metadata(classifier string, paths ...string) pkg.BinarySignature {
+	return pkg.BinarySignature{
 		Matches: []pkg.ClassifierMatch{
 			match(classifier, paths...),
 		},
@@ -819,8 +819,8 @@ func assertPackagesAreEqual(t *testing.T, expected pkg.Package, p pkg.Package) {
 		}
 	}
 
-	m1 := expected.Metadata.(pkg.BinaryMetadata).Matches
-	m2 := p.Metadata.(pkg.BinaryMetadata).Matches
+	m1 := expected.Metadata.(pkg.BinarySignature).Matches
+	m2 := p.Metadata.(pkg.BinarySignature).Matches
 	matches := true
 	if len(m1) == len(m2) {
 		for i, m1 := range m1 {
