@@ -9,18 +9,21 @@ import (
 
 	"github.com/google/go-cmp/cmp"
 	"github.com/google/go-cmp/cmp/cmpopts"
+	"github.com/sanity-io/litter"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 
 	"github.com/anchore/stereoscope/pkg/imagetest"
 	"github.com/anchore/syft/syft/artifact"
+	"github.com/anchore/syft/syft/file"
 	"github.com/anchore/syft/syft/linux"
 	"github.com/anchore/syft/syft/pkg"
 	"github.com/anchore/syft/syft/pkg/cataloger/generic"
 	"github.com/anchore/syft/syft/source"
 )
 
-type locationComparer func(x, y source.Location) bool
+type locationComparer func(x, y file.Location) bool
+type licenseComparer func(x, y pkg.License) bool
 
 type CatalogTester struct {
 	expectedPkgs                   []pkg.Package
@@ -31,17 +34,19 @@ type CatalogTester struct {
 	ignoreUnfulfilledPathResponses map[string][]string
 	ignoreAnyUnfulfilledPaths      []string
 	env                            *generic.Environment
-	reader                         source.LocationReadCloser
-	resolver                       source.FileResolver
+	reader                         file.LocationReadCloser
+	resolver                       file.Resolver
 	wantErr                        require.ErrorAssertionFunc
 	compareOptions                 []cmp.Option
 	locationComparer               locationComparer
+	licenseComparer                licenseComparer
 }
 
 func NewCatalogTester() *CatalogTester {
 	return &CatalogTester{
 		wantErr:          require.NoError,
 		locationComparer: DefaultLocationComparer,
+		licenseComparer:  DefaultLicenseComparer,
 		ignoreUnfulfilledPathResponses: map[string][]string{
 			"FilesByPath": {
 				// most catalogers search for a linux release, which will not be fulfilled in testing
@@ -55,14 +60,33 @@ func NewCatalogTester() *CatalogTester {
 	}
 }
 
-func DefaultLocationComparer(x, y source.Location) bool {
+func DefaultLocationComparer(x, y file.Location) bool {
 	return cmp.Equal(x.Coordinates, y.Coordinates) && cmp.Equal(x.VirtualPath, y.VirtualPath)
 }
 
+func DefaultLicenseComparer(x, y pkg.License) bool {
+	return cmp.Equal(x, y, cmp.Comparer(DefaultLocationComparer), cmp.Comparer(
+		func(x, y file.LocationSet) bool {
+			xs := x.ToSlice()
+			ys := y.ToSlice()
+			if len(xs) != len(ys) {
+				return false
+			}
+			for i, xe := range xs {
+				ye := ys[i]
+				if !DefaultLocationComparer(xe, ye) {
+					return false
+				}
+			}
+			return true
+		},
+	))
+}
+
 func (p *CatalogTester) FromDirectory(t *testing.T, path string) *CatalogTester {
 	t.Helper()
 
-	s, err := source.NewFromDirectory(path)
+	s, err := source.NewFromDirectoryPath(path)
 	require.NoError(t, err)
 
 	resolver, err := s.FileResolver(source.AllLayersScope)
@@ -78,16 +102,16 @@ func (p *CatalogTester) FromFile(t *testing.T, path string) *CatalogTester {
 	fixture, err := os.Open(path)
 	require.NoError(t, err)
 
-	p.reader = source.LocationReadCloser{
-		Location:   source.NewLocation(fixture.Name()),
+	p.reader = file.LocationReadCloser{
+		Location:   file.NewLocation(fixture.Name()),
 		ReadCloser: fixture,
 	}
 	return p
 }
 
 func (p *CatalogTester) FromString(location, data string) *CatalogTester {
-	p.reader = source.LocationReadCloser{
-		Location:   source.NewLocation(location),
+	p.reader = file.LocationReadCloser{
+		Location:   file.NewLocation(location),
 		ReadCloser: io.NopCloser(strings.NewReader(data)),
 	}
 	return p
@@ -117,7 +141,7 @@ func (p *CatalogTester) WithErrorAssertion(a require.ErrorAssertionFunc) *Catalo
 	return p
 }
 
-func (p *CatalogTester) WithResolver(r source.FileResolver) *CatalogTester {
+func (p *CatalogTester) WithResolver(r file.Resolver) *CatalogTester {
 	p.resolver = r
 	return p
 }
@@ -126,7 +150,7 @@ func (p *CatalogTester) WithImageResolver(t *testing.T, fixtureName string) *Cat
 	t.Helper()
 	img := imagetest.GetFixtureImage(t, "docker-archive", fixtureName)
 
-	s, err := source.NewFromImage(img, fixtureName)
+	s, err := source.NewFromStereoscopeImageObject(img, fixtureName, nil)
 	require.NoError(t, err)
 
 	r, err := s.FileResolver(source.SquashedScope)
@@ -136,9 +160,29 @@ func (p *CatalogTester) WithImageResolver(t *testing.T, fixtureName string) *Cat
 }
 
 func (p *CatalogTester) IgnoreLocationLayer() *CatalogTester {
-	p.locationComparer = func(x, y source.Location) bool {
+	p.locationComparer = func(x, y file.Location) bool {
 		return cmp.Equal(x.Coordinates.RealPath, y.Coordinates.RealPath) && cmp.Equal(x.VirtualPath, y.VirtualPath)
 	}
+
+	// we need to update the license comparer to use the ignored location layer
+	p.licenseComparer = func(x, y pkg.License) bool {
+		return cmp.Equal(x, y, cmp.Comparer(p.locationComparer), cmp.Comparer(
+			func(x, y file.LocationSet) bool {
+				xs := x.ToSlice()
+				ys := y.ToSlice()
+				if len(xs) != len(ys) {
+					return false
+				}
+				for i, xe := range xs {
+					ye := ys[i]
+					if !p.locationComparer(xe, ye) {
+						return false
+					}
+				}
+
+				return true
+			}))
+	}
 	return p
 }
 
@@ -209,14 +253,33 @@ func (p *CatalogTester) TestCataloger(t *testing.T, cataloger pkg.Cataloger) {
 	}
 }
 
+var relationshipStringer = litter.Options{
+	Compact:           true,
+	StripPackageNames: false,
+	HidePrivateFields: true, // we want to ignore package IDs
+	HideZeroValues:    true,
+	StrictGo:          true,
+	//FieldExclusions: ...  // these can be added for future values that need to be ignored
+	//FieldFilter: ...
+}
+
+func relationshipLess(x, y artifact.Relationship) bool {
+	// we just need a stable sort, the ordering does not need to be sensible
+	xStr := relationshipStringer.Sdump(x)
+	yStr := relationshipStringer.Sdump(y)
+	return xStr < yStr
+}
+
+// nolint:funlen
 func (p *CatalogTester) assertPkgs(t *testing.T, pkgs []pkg.Package, relationships []artifact.Relationship) {
 	t.Helper()
 
 	p.compareOptions = append(p.compareOptions,
 		cmpopts.IgnoreFields(pkg.Package{}, "id"), // note: ID is not deterministic for test purposes
 		cmpopts.SortSlices(pkg.Less),
+		cmpopts.SortSlices(relationshipLess),
 		cmp.Comparer(
-			func(x, y source.LocationSet) bool {
+			func(x, y file.LocationSet) bool {
 				xs := x.ToSlice()
 				ys := y.ToSlice()
 
@@ -233,6 +296,30 @@ func (p *CatalogTester) assertPkgs(t *testing.T, pkgs []pkg.Package, relationshi
 				return true
 			},
 		),
+		cmp.Comparer(
+			func(x, y pkg.LicenseSet) bool {
+				xs := x.ToSlice()
+				ys := y.ToSlice()
+
+				if len(xs) != len(ys) {
+					return false
+				}
+				for i, xe := range xs {
+					ye := ys[i]
+					if !p.licenseComparer(xe, ye) {
+						return false
+					}
+				}
+
+				return true
+			},
+		),
+		cmp.Comparer(
+			p.locationComparer,
+		),
+		cmp.Comparer(
+			p.licenseComparer,
+		),
 	)
 
 	{
@@ -242,12 +329,15 @@ func (p *CatalogTester) assertPkgs(t *testing.T, pkgs []pkg.Package, relationshi
 		opts = append(opts, p.compareOptions...)
 		opts = append(opts, cmp.Reporter(&r))
 
+		// order should not matter
+		pkg.Sort(p.expectedPkgs)
+		pkg.Sort(pkgs)
+
 		if diff := cmp.Diff(p.expectedPkgs, pkgs, opts...); diff != "" {
 			t.Log("Specific Differences:\n" + r.String())
 			t.Errorf("unexpected packages from parsing (-expected +actual)\n%s", diff)
 		}
 	}
-
 	{
 		var r diffReporter
 		var opts []cmp.Option
@@ -255,6 +345,10 @@ func (p *CatalogTester) assertPkgs(t *testing.T, pkgs []pkg.Package, relationshi
 		opts = append(opts, p.compareOptions...)
 		opts = append(opts, cmp.Reporter(&r))
 
+		// order should not matter
+		pkg.SortRelationships(p.expectedRelationships)
+		pkg.SortRelationships(relationships)
+
 		if diff := cmp.Diff(p.expectedRelationships, relationships, opts...); diff != "" {
 			t.Log("Specific Differences:\n" + r.String())
 
@@ -279,7 +373,7 @@ func AssertPackagesEqual(t *testing.T, a, b pkg.Package) {
 	opts := []cmp.Option{
 		cmpopts.IgnoreFields(pkg.Package{}, "id"), // note: ID is not deterministic for test purposes
 		cmp.Comparer(
-			func(x, y source.LocationSet) bool {
+			func(x, y file.LocationSet) bool {
 				xs := x.ToSlice()
 				ys := y.ToSlice()
 
@@ -296,6 +390,30 @@ func AssertPackagesEqual(t *testing.T, a, b pkg.Package) {
 				return true
 			},
 		),
+		cmp.Comparer(
+			func(x, y pkg.LicenseSet) bool {
+				xs := x.ToSlice()
+				ys := y.ToSlice()
+
+				if len(xs) != len(ys) {
+					return false
+				}
+				for i, xe := range xs {
+					ye := ys[i]
+					if !DefaultLicenseComparer(xe, ye) {
+						return false
+					}
+				}
+
+				return true
+			},
+		),
+		cmp.Comparer(
+			DefaultLocationComparer,
+		),
+		cmp.Comparer(
+			DefaultLicenseComparer,
+		),
 	}
 
 	if diff := cmp.Diff(a, b, opts...); diff != "" {
