@@ -123,14 +123,13 @@ func getPackage(component nativeImageComponent) pkg.Package {
 		cpes = append(cpes, c)
 	}
 	return pkg.Package{
-		Name:         component.Name,
-		Version:      component.Version,
-		Language:     pkg.Java,
-		Type:         pkg.GraalVMNativeImagePkg,
-		MetadataType: pkg.JavaMetadataType,
-		FoundBy:      nativeImageCatalogerName,
-		Metadata: pkg.JavaMetadata{
-			PomProperties: &pkg.PomProperties{
+		Name:     component.Name,
+		Version:  component.Version,
+		Language: pkg.Java,
+		Type:     pkg.GraalVMNativeImagePkg,
+		FoundBy:  nativeImageCatalogerName,
+		Metadata: pkg.JavaArchive{
+			PomProperties: &pkg.JavaPomProperties{
 				GroupID: component.Group,
 			},
 		},
