@@ -68,14 +68,13 @@ func TestParseNativeImageSbom(t *testing.T) {
 			fixture: "test-fixtures/graalvm-sbom/micronaut.json",
 			expected: []pkg.Package{
 				{
-					Name:         "netty-codec-http2",
-					Version:      "4.1.73.Final",
-					Language:     pkg.Java,
-					Type:         pkg.GraalVMNativeImagePkg,
-					MetadataType: pkg.JavaMetadataType,
-					FoundBy:      nativeImageCatalogerName,
-					Metadata: pkg.JavaMetadata{
-						PomProperties: &pkg.PomProperties{
+					Name:     "netty-codec-http2",
+					Version:  "4.1.73.Final",
+					Language: pkg.Java,
+					Type:     pkg.GraalVMNativeImagePkg,
+					FoundBy:  nativeImageCatalogerName,
+					Metadata: pkg.JavaArchive{
+						PomProperties: &pkg.JavaPomProperties{
 							GroupID: "io.netty",
 						},
 					},
