@@ -15,7 +15,8 @@ import (
 	"github.com/anchore/syft/syft/pkg/cataloger/generic"
 )
 
-// parseWheelOrEgg takes the primary metadata file reference and returns the python package it represents.
+// parseWheelOrEgg takes the primary metadata file reference and returns the python package it represents. Contained
+// fields are governed by the PyPA core metadata specification (https://packaging.python.org/en/latest/specifications/core-metadata/).
 func parseWheelOrEgg(resolver file.Resolver, _ *generic.Environment, reader file.LocationReadCloser) ([]pkg.Package, []artifact.Relationship, error) {
 	pd, sources, err := assembleEggOrWheelMetadata(resolver, reader.Location)
 	if err != nil {
@@ -125,6 +126,27 @@ func fetchTopLevelPackages(resolver file.Resolver, metadataLocation file.Locatio
 	return pkgs, sources, nil
 }
 
+type directURLOrigin struct {
+	URL         string      `json:"url"`
+	VCSInfo     vcsInfo     `json:"vcs_info"`
+	ArchiveInfo archiveInfo `json:"archive_info"`
+	DirInfo     dirInfo     `json:"dir_info"`
+}
+
+type dirInfo struct {
+	Editable bool `json:"editable"`
+}
+
+type archiveInfo struct {
+	Hash string `json:"hash"`
+}
+
+type vcsInfo struct {
+	CommitID          string `json:"commit_id"`
+	VCS               string `json:"vcs"`
+	RequestedRevision string `json:"requested_revision"`
+}
+
 func fetchDirectURLData(resolver file.Resolver, metadataLocation file.Location) (d *pkg.PythonDirectURLOriginInfo, sources []file.Location, err error) {
 	parentDir := filepath.Dir(metadataLocation.RealPath)
 	directURLPath := filepath.Join(parentDir, "direct_url.json")
@@ -147,7 +169,7 @@ func fetchDirectURLData(resolver file.Resolver, metadataLocation file.Location)
 		return nil, nil, err
 	}
 
-	var directURLJson pkg.DirectURLOrigin
+	var directURLJson directURLOrigin
 	if err := json.Unmarshal(buffer, &directURLJson); err != nil {
 		return nil, nil, err
 	}
