@@ -23,15 +23,14 @@ func newGemfileLockPackage(name, version string, locations ...file.Location) pkg
 
 func newGemspecPackage(m gemData, gemSpecLocation file.Location) pkg.Package {
 	p := pkg.Package{
-		Name:         m.Name,
-		Version:      m.Version,
-		Locations:    file.NewLocationSet(gemSpecLocation.WithAnnotation(pkg.EvidenceAnnotationKey, pkg.PrimaryEvidenceAnnotation)),
-		Licenses:     pkg.NewLicenseSet(pkg.NewLicensesFromLocation(gemSpecLocation, m.Licenses...)...),
-		PURL:         packageURL(m.Name, m.Version),
-		Language:     pkg.Ruby,
-		Type:         pkg.GemPkg,
-		MetadataType: pkg.GemMetadataType,
-		Metadata:     m.GemMetadata,
+		Name:      m.Name,
+		Version:   m.Version,
+		Locations: file.NewLocationSet(gemSpecLocation.WithAnnotation(pkg.EvidenceAnnotationKey, pkg.PrimaryEvidenceAnnotation)),
+		Licenses:  pkg.NewLicenseSet(pkg.NewLicensesFromLocation(gemSpecLocation, m.Licenses...)...),
+		PURL:      packageURL(m.Name, m.Version),
+		Language:  pkg.Ruby,
+		Type:      pkg.GemPkg,
+		Metadata:  m.RubyGemspec,
 	}
 
 	p.SetID()
