@@ -6,8 +6,9 @@ import (
 
 	"github.com/stretchr/testify/require"
 
-	"github.com/anchore/syft/syft/formats"
-	"github.com/anchore/syft/syft/formats/template"
+	"github.com/anchore/syft/cmd/syft/cli/options"
+	"github.com/anchore/syft/syft/format"
+	"github.com/anchore/syft/syft/format/template"
 )
 
 func TestAllFormatsExpressible(t *testing.T) {
@@ -20,9 +21,15 @@ func TestAllFormatsExpressible(t *testing.T) {
 		},
 		assertSuccessfulReturnCode,
 	}
-	formatNames := formats.AllIDs()
-	require.NotEmpty(t, formatNames)
-	for _, o := range formatNames {
+
+	opts := options.DefaultOutput()
+	encoders, err := opts.Encoders()
+	require.NoError(t, err)
+
+	encs := format.NewEncoderCollection(encoders...)
+	formatIDs := encs.IDs()
+	require.NotEmpty(t, formatIDs)
+	for _, o := range formatIDs {
 		t.Run(fmt.Sprintf("format:%s", o), func(t *testing.T) {
 			args := []string{"dir:./test-fixtures/image-pkg-coverage", "-o", string(o)}
 			if o == template.ID {
